
# Slot: dtype




URI: [nwb_schema_language:dtype](https://w3id.org/p2p_ld/nwb-schema-language/dtype)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children

 *  [CompoundDtype➞dtype](CompoundDtype_dtype.md)

## Used by

 * [Attribute](Attribute.md)
 * [Dataset](Dataset.md)
 * [DtypeMixin](DtypeMixin.md)
